=========================================
``psyclone.psyir.nodes.structure_member``
=========================================

.. automodule:: psyclone.psyir.nodes.structure_member

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.structure_member


Classes
=======

- :py:class:`StructureMember`:
  Node representing a membership expression of the parent's Reference that


.. autoclass:: StructureMember
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: StructureMember
      :parts: 1
